==> opennms-webapp-1.7.3-sources.jar: org/opennms/web/inventory/InventoryWrapper.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com///

package org.opennms.web.inventory;

import java.util.Date;

public class InventoryWrapper {
    
    private String version;
    private Date date;
    private String group;
    private String urlViewVC;
    
    
    public InventoryWrapper(String version, Date date, String group, String urlViewVC){
        this.version = version;
        this.date = date;
        this.group = group;
        this.urlViewVC = urlViewVC;
    }

    public String getVersion(){
        return version;
    }
    public Date getDate() {
        return date;
    }
    public String getGroup(){
        return group;
    }
    public String getUrlViewVC(){
        return urlViewVC;
    }
}

==> opennms-webapp-1.9.5-sources.jar: org/opennms/web/inventory/InventoryWrapper.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com///

package org.opennms.web.inventory;

import java.util.Date;

/**
 * <p>InventoryWrapper class.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public class InventoryWrapper {
    
    private String version;
    private Date date;
    private String group;
    private String urlViewVC;
    
    
    /**
     * <p>Constructor for InventoryWrapper.</p>
     *
     * @param version a {@link java.lang.String} object.
     * @param date a java$util$Date object.
     * @param group a {@link java.lang.String} object.
     * @param urlViewVC a {@link java.lang.String} object.
     */
    public InventoryWrapper(String version, Date date, String group, String urlViewVC){
        this.version = version;
        this.date = date;
        this.group = group;
        this.urlViewVC = urlViewVC;
    }

    /**
     * <p>Getter for the field <code>version</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getVersion(){
        return version;
    }
    /**
     * <p>Getter for the field <code>date</code>.</p>
     *
     * @return a java$util$Date object.
     */
    public Date getDate() {
        return date;
    }
    /**
     * <p>Getter for the field <code>group</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getGroup(){
        return group;
    }
    /**
     * <p>Getter for the field <code>urlViewVC</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getUrlViewVC(){
        return urlViewVC;
    }
}
